Contribution
============
This is an open-source project which was created to learn and to
have fast and easy access of Quantum Processing Units as a python
developer. This project can be optimized and extended, but
alone this is quite a difficult task. If you want to contribute,
feel free to create an issue or a pull request. If you plan to put
more than a couple of hours into extending this package, contact me please before
you begin to work on it mail@haraldheckmann.de.
